Sertifikāti | OiRA
Description: Atkarībā no valsts OiRA partnera / rīka izstrādātāja pieejas var būt iespējams saņemt jūsu riska novērtējuma sertifikātu. Lai uzzinātu sīkāku informāciju par šādu sertifikātu priekšrocībām, lūdzam sazināties ar savu valsts OiRA partneri.

Temati

# Sertifikāti

Atkarībā no valsts OiRA partnera / rīka izstrādātāja pieejas var būt iespējams saņemt jūsu riska novērtējuma sertifikātu. Lai uzzinātu sīkāku informāciju par šādu sertifikātu priekšrocībām, lūdzam sazināties ar savu valsts OiRA partneri.

Kā iegūt sertifikātu

## Veiciet pilnu riska novērtējumu

Kad jūs veiksiet riska novērtējumu, OiRA reģistrēs jūsu progresu. Kad būsiet novērtējis vairākus riskus, rīks informēs jūs par iespēju pēc pilna riska novērtējuma pabeigšanas saņemt sertifikātu. Katrs valsts OiRA partneris / rīka izstrādātājs nosaka slieksni (procentuālo daļu) “pilna” riska novērtējuma definēšanai. Sertifikāts ir pieejams, izmantojot pogu “Statuss”, izvēlnē ekrāna kreisajā pusē.

Statusa lapa rāda, ka ir pieejams sertifikāts.

## Apskatiet un publicējiet savu sertifikātu

Noklikšķinot uz pogas “Skatīt sertifikātu”, jums tiks prasīts ievadīt uzņēmuma nosaukumu, kas ir jānorāda sertifikātā. Atkarībā no nacionālajiem iestatījumiem jums var prasīt ievadīt papildu datus, lai nodrošinātu, ka sertifikātā ir sniegta visa vajadzīgā informācija.

Ievadiet visu sertifikātam vajadzīgo informāciju.

Ja izdarīsiet atzīmi rūtiņā “Publiskot”, parādīsies unikāla saite (URL) uz jūsu sertifikātu. Nokopējiet šo saiti un kopīgojiet to ar attiecīgajām personām, lai pierādītu, ka esat veicis savu riska novērtējumu.

Piezīme: Tiks publiskoti tikai šajā lapā norādītie dati. Šī saite nav pieejama OiRA tīmekļa vietnes izvēlnē — tā attiecas tikai uz jums. Tomēr teorētiski ikviens, kurš pārlūko internetu, var redzēt jūsu izveidoto sertifikātu.

Sertifikāts tikai apliecina to, ka esat reaģējis uz noteiktu skaitu risku riska novērtēšanas rīkā, bet nesniedz citu informāciju. Konkrētās atbildes uz riska novērtējumu, kas sniegtas, aizpildot OiRA rīku, varat aplūkot tikai jūs, bet neviens cits.

Scroll to top Load toolbar…
Back

## 5-certificates.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More